@@ -1,5 +1,6 @@
 from content_editor.models import Type
 from django import forms
+from django.core import validators
 from django.db import models
 from django.db.models import signals
 from django.db.models.fields import BLANK_CHOICE_DASH
@@ -67,12 +68,43 @@ class ConfiguredForm(models.Model):
 signals.class_prepared.connect(ConfiguredForm.fill_form_choices)
 
 
+class KeyField(models.CharField):
+    def __init__(self, **kwargs):
+        kwargs.setdefault("verbose_name", _("key"))
+        kwargs.setdefault("max_length", 50)
+        kwargs.setdefault(
+            "validators",
+            [
+                validators.RegexValidator(
+                    r"^[a-z0-9_]+$",
+                    message=_(
+                        "Enter a value consisting only of lowercase letters,"
+                        " numbers and the underscore."
+                    ),
+                ),
+            ],
+        )
+        kwargs.setdefault(
+            "help_text",
+            _(
+                "Data is saved using this key. Changing it may result in data loss."
+                " This field only allows a-z, 0-9 and _ as characters."
+            ),
+        )
+        super().__init__(**kwargs)
+
+    def deconstruct(self):
+        name, path, args, kwargs = super().deconstruct()
+        return name, "django.db.models.CharField", args, kwargs
+
+
 class SimpleFieldBase(models.Model):
     class Type(models.TextChoices):
         TEXT = "text", _("text field")
         EMAIL = "email", _("email address field")
         URL = "url", _("URL field")
         DATE = "date", _("date field")
+        INTEGER = "integer", _("integer field")
         TEXTAREA = "textarea", _("multiline text field")
         CHECKBOX = "checkbox", _("checkbox field")
         SELECT = "select", _("dropdown field")
@@ -81,12 +113,7 @@ class SimpleFieldBase(models.Model):
     type = models.CharField(_("type"), max_length=1000, editable=False)
 
     label = models.CharField(_("label"), max_length=1000)
-    key = models.SlugField(
-        _("key"),
-        help_text=_(
-            "Data is saved using this key. Changing it may result in data loss."
-        ),
-    )
+    key = KeyField()
     is_required = models.BooleanField(_("is required"), default=True)
     help_text = models.CharField(
         _("help text"),
@@ -221,10 +248,11 @@ class SimpleFieldBase(models.Model):
                 self.key: forms.ChoiceField(choices=choices, **field_kw),
             }
 
-        elif self.type in {T.EMAIL, T.URL}:
+        elif self.type in {T.EMAIL, T.URL, T.INTEGER}:
             field = {
                 T.EMAIL: forms.EmailField,
                 T.URL: forms.URLField,
+                T.INTEGER: forms.IntegerField,
             }[self.type]
             return {
                 self.key: field(
